@@ -126,10 +126,10 @@ void g_mozilla_connectivity_handle (GMozillaEngine *self, gint event)
                 g_mozilla_connectivity_set_proxy();
                 ULOG_INFO_F("Engine: %p: LoadUrl: '%s'\n", self->engine, self->will_open_location);
                 self->waiting_connection = FALSE;
-                if (!g_str_has_prefix(self->will_open_location, "file://"))
+                if (self->will_open_location && !g_str_has_prefix(self->will_open_location, "file://"))
                     gtk_moz_embed_load_url(GTK_MOZ_EMBED(self->engine), self->will_open_location);
             } else if (self->progress_bar_state == 0 && !self->is_loading) {
-                g_signal_emit_by_name(G_OBJECT(self), "finished_loading", 0, self->last_net_status, 15000, TRUE);
+                g_signal_emit_by_name(G_OBJECT(self), "finished_loading", 0, self->last_net_status, self->page_size, TRUE);
                 self->progress_bar_state = -1;
             }
               /*else if (self->is_download)
@@ -144,7 +144,7 @@ void g_mozilla_connectivity_handle (GMozillaEngine *self, gint event)
         g_mozilla_web_pause_all_transfer_item (G_MOZILLA_WEB(webglobal));
 
         // from g_mozilla_engine_stop_load body
-        if (self->is_loading) {
+        if (self->is_loading && self->will_open_location && !g_str_has_prefix(self->will_open_location, "file://")) {
             g_mozilla_connectivity_check_buggy();
             gtk_moz_embed_stop_load(GTK_MOZ_EMBED(self->engine));
             self->is_loading = FALSE;
@@ -168,7 +168,7 @@ void g_mozilla_connectivity_handle (GMozillaEngine *self, gint event)
     }
     can_connect = FALSE;
     if (self && self->waiting_connection) {
-        g_signal_emit_by_name(G_OBJECT(self), "finished_loading", 0, self->last_net_status, 15000, TRUE);
+        g_signal_emit_by_name(G_OBJECT(self), "finished_loading", 0, self->last_net_status, self->page_size, TRUE);
         self->progress_bar_state = -1;
         self->user_iteraction_happens = FALSE;
     }
@@ -257,6 +257,7 @@ g_mozilla_connectivity_set_global (GMozillaWeb *self)
     DBusConnection *sys_conn;
     char filter[256] = {0};
     sys_conn = dbus_bus_get(DBUS_BUS_SYSTEM, NULL);
+    g_return_if_fail(sys_conn);
     dbus_connection_add_filter (sys_conn, connectivity_cb, self, NULL);
 #ifdef USE_CONIC
     g_snprintf(filter, sizeof (filter),
@@ -429,8 +430,10 @@ void g_mozilla_connectivity_set_proxy ()
                                            NULL);
 #endif
         //g_print ("%s\n", autoconf);
-        if (autoconf)
+        if (autoconf) {
             gtk_moz_embed_common_set_pref (G_TYPE_STRING, G_MOZILLA_PREF_AUTOCONFIG_URL_PROXY, autoconf);
+            EAL_GFREE(autoconf);
+        }
     } else if (g_ascii_strcasecmp(proxytype, G_MOZILLA_PROXY_MANUAL) == 0) {
         gval = 1;
         gtk_moz_embed_common_set_pref (G_TYPE_INT, G_MOZILLA_PREF_PROXY_TYPE, &gval);
@@ -441,9 +444,10 @@ void g_mozilla_connectivity_set_proxy ()
 #endif
         //printf("HTTP PROXY: %s\n", proxy_http);
         if (proxy_http) {
-            if (g_str_has_prefix(proxy_http, "http://"))
-              proxy_http += 7;
-            gtk_moz_embed_common_set_pref (G_TYPE_STRING, G_MOZILLA_PREF_HTTP_PROXY, proxy_http);
+            gtk_moz_embed_common_set_pref(G_TYPE_STRING,
+                                          G_MOZILLA_PREF_HTTP_PROXY,
+                                          g_str_has_prefix(proxy_http, "http://")?&proxy_http[7]:proxy_http);
+            EAL_GFREE(proxy_http);
 #ifdef USE_GCONF
             proxy_http_port = gconf_client_get_int(gconf_client,
                                                    "/system/http_proxy/port",
@@ -462,9 +466,10 @@ void g_mozilla_connectivity_set_proxy ()
 #endif
         //printf("HTTPS PROXY: %s\n", proxy_http);
         if (proxy_https) {
-            if (g_str_has_prefix(proxy_https, "https://"))
-              proxy_https += 8;
-            gtk_moz_embed_common_set_pref (G_TYPE_STRING, G_MOZILLA_PREF_HTTPS_PROXY, proxy_https);
+            gtk_moz_embed_common_set_pref(G_TYPE_STRING,
+                                          G_MOZILLA_PREF_HTTPS_PROXY,
+                                          g_str_has_prefix(proxy_https, "https://")?&proxy_https[8]:proxy_https);
+            EAL_GFREE(proxy_https);
 #ifdef USE_GCONF
             proxy_https_port = gconf_client_get_int(gconf_client,
                                                 "/system/proxy/secure_port",
@@ -483,9 +488,10 @@ void g_mozilla_connectivity_set_proxy ()
         //printf("FTP PROXY: %s\n", proxy_ftp);
 #endif
         if (proxy_ftp) {
-            if (g_str_has_prefix(proxy_ftp, "ftp://"))
-              proxy_ftp += 6;
-            gtk_moz_embed_common_set_pref (G_TYPE_STRING, G_MOZILLA_PREF_FTP_PROXY, proxy_ftp);
+            gtk_moz_embed_common_set_pref(G_TYPE_STRING,
+                                          G_MOZILLA_PREF_FTP_PROXY,
+                                          g_str_has_prefix(proxy_ftp, "ftp://")?&proxy_ftp[6]:proxy_ftp);
+            EAL_GFREE(proxy_ftp);
 #ifdef USE_GCONF
             proxy_ftp_port = gconf_client_get_int(gconf_client,
                                                   "/system/proxy/ftp_port",
@@ -509,5 +515,7 @@ void g_mozilla_connectivity_set_proxy ()
             gtk_moz_embed_common_set_pref (G_TYPE_STRING, G_MOZILLA_PREF_OMITTED_HOSTS_PROXY, omit_proxy);
     }
     gtk_moz_embed_common_save_prefs ();
+    EAL_IF_GFREE(proxytype);
+    EAL_IF_GFREE(omit_proxy);
     TRACE_LOG();
 }
