@@ -112,9 +112,11 @@ g_mozilla_web_destroy (GMozillaWeb *self)
         self->global = NULL;
     }
     EAL_IF_GFREE(self->anime_cursor);
-    /* TBD | May be something else should be destroyed... */
-    if(self->disabled_pllist)
-        g_mozilla_plugin_enable_plugins (&self->disabled_pllist);
+    if(self->default_cursor)
+    {
+        gdk_cursor_unref(self->default_cursor);
+        self->default_cursor == NULL;
+    }	
 
     g_mozilla_connectivity_unset_global(self);
     gtk_moz_embed_pop_startup();
@@ -986,6 +988,10 @@ g_mozilla_web_notify_plugins (GMozillaWeb *self, gint event)
     }
     if(status)
       gtk_moz_embed_common_reload_plugins ();
+    if (G_WEB_PLUGINS_LOW_MEMORY != event)
+     return;
+    gtk_moz_embed_common_observe (NULL, NULL, "memory-pressure", (gunichar *) "h\0e\0a\0p\0-\0m\0i\0n\0i\0m\0i\0z\0e\0\0");
+    malloc_trim (0);
 }
 
 static GWebStatus
@@ -1398,6 +1404,7 @@ g_mozilla_web_instance_init (GTypeInstance *instance, gpointer  g_class)
     G_MOZILLA_WEB(instance)->disabled_pllist = NULL;
     G_MOZILLA_WEB(instance)->mCertContexts = NULL;
     G_MOZILLA_WEB(instance)->anime_cursor = g_new0(AnimeCursor, 1);
+    G_MOZILLA_WEB(instance)->default_cursor = gdk_cursor_new (GDK_LEFT_PTR);
 #ifdef MOZEAL_LOGGING
     if (g_strrstr(g_getenv("MOZEAL_LOG"), "trace") || g_str_has_prefix(g_getenv("MOZEAL_LOG"), "all")) {
         bmozeal_trace = TRUE;
@@ -1705,11 +1712,21 @@ g_mozilla_web_set_default_config (GMozillaWeb *self)
         g_free(sval);
     sval = NULL;
 
+    gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, G_MOZILLA_PREF_SSR_ENABLED, &bfval);
+
     // activating snav
     gtk_moz_embed_common_set_pref(G_TYPE_INT, G_MOZILLA_PREF_SPATIAL_NAVIGATION, &gval);
-    gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, "snav.enabled", &btval);
-    gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, "snav.ignoreTextFields", &bfval);
-    gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, "snav.disableJS", &btval);
+    if (!gtk_moz_embed_common_get_pref(G_TYPE_BOOLEAN, "snav.enabled", &bval))
+        gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, "snav.enabled", &btval);
+    
+    if (!gtk_moz_embed_common_get_pref(G_TYPE_BOOLEAN, "snav.ignoreTextFields", &bval))
+        gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, "snav.ignoreTextFields", &bfval);
+    
+    if (!gtk_moz_embed_common_get_pref(G_TYPE_BOOLEAN, "snav.disableJS", &bval))
+        gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, "snav.disableJS", &bfval);
+
+    gval = 7;
+    gtk_moz_embed_common_set_pref (G_TYPE_INT, "accessibility.tabfocus", &gval);
 
     // focus border styling
 /*    gval = 3;
@@ -1798,6 +1815,9 @@ g_mozilla_web_set_default_config (GMozillaWeb *self)
     if (!gtk_moz_embed_common_get_pref(G_TYPE_INT, G_MOZILLA_PREF_ENABLE_POPUP_WINDOWS, &gval))
         gtk_moz_embed_common_set_pref(G_TYPE_INT, G_MOZILLA_PREF_ENABLE_POPUP_WINDOWS, &gval);
 
+    if (!gtk_moz_embed_common_get_pref(G_TYPE_BOOLEAN, G_MOZILLA_PREF_AUTOMATIC_IMAGE_RESIZING, &bval))
+        gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, G_MOZILLA_PREF_AUTOMATIC_IMAGE_RESIZING, &btval);
+
     bval = FALSE;
     if (!gtk_moz_embed_common_get_pref(G_TYPE_BOOLEAN, G_MOZILLA_PREF_OPEN_POPUP_DURING_LOAD, &bval))
         gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, G_MOZILLA_PREF_OPEN_POPUP_DURING_LOAD, &bval);
@@ -1844,8 +1864,8 @@ g_mozilla_web_set_default_config (GMozillaWeb *self)
     if (!gtk_moz_embed_common_get_pref(G_TYPE_INT, G_MOZILLA_PREF_BROWSER_HISTORY_EXPIRE_DAYS, &gval))
         gtk_moz_embed_common_set_pref(G_TYPE_INT, G_MOZILLA_PREF_BROWSER_HISTORY_EXPIRE_DAYS, &gval);
 
-    if (!gtk_moz_embed_common_get_pref(G_TYPE_BOOLEAN, G_MOZILLA_PREF_DISABLE_ZOOM_NAV_CHANGE, &bval))
-        gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, G_MOZILLA_PREF_DISABLE_ZOOM_NAV_CHANGE, &btval);
+    if (!gtk_moz_embed_common_get_pref(G_TYPE_BOOLEAN, G_MOZILLA_PREF_PRESERVE_ZOOM_NAV_CHANGE, &bval))
+        gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, G_MOZILLA_PREF_PRESERVE_ZOOM_NAV_CHANGE, &btval);
 
     if (!gtk_moz_embed_common_get_pref(G_TYPE_BOOLEAN, G_MOZILLA_PREF_JSFOCUS_FOR_VISIBLE_AREA, &bval))
         gtk_moz_embed_common_set_pref(G_TYPE_BOOLEAN, G_MOZILLA_PREF_JSFOCUS_FOR_VISIBLE_AREA, &btval);
